Method: NMatrix.seq
- Defined in:
- lib/nmatrix/shortcuts.rb
.seq(shape, options = {}) ⇒ Object
call-seq:
seq(shape) -> NMatrix
seq(shape, options) -> NMatrix
bindgen(shape) -> NMatrix of :byte
indgen(shape) -> NMatrix of :int64
findgen(shape) -> NMatrix of :float32
dindgen(shape) -> NMatrix of :float64
cindgen(shape) -> NMatrix of :complex64
zindgen(shape) -> NMatrix of :complex128
rbindgen(shape) -> NMatrix of :object
Creates a matrix filled with a sequence of integers starting at zero.
-
Arguments :
-
shape-> Array (or integer for square matrix) specifying the dimensions. -
options-> (optional) Options permissible for NMatrix#initialize
-
-
Returns :
-
NMatrix filled with values 0 through
size.
-
Examples:
NMatrix.seq(2) # => 0 1
2 3
NMatrix.seq([3, 3], dtype: :float32) # => 0.0 1.0 2.0
3.0 4.0 5.0
6.0 7.0 8.0
838 839 840 841 842 843 844 845 |
# File 'lib/nmatrix/shortcuts.rb', line 838 def seq(shape, ={}) # Construct the values of the final matrix based on the dimension. values = (0 ... NMatrix.size(shape)).to_a # It'll produce :int32, except if a dtype is provided. NMatrix.new(shape, values, {:stype => :dense}.merge()) end |